repo
stringclasses
15 values
fix_commit
stringlengths
40
40
buggy_commit
stringlengths
40
40
message
stringlengths
3
64.3k
files
listlengths
1
300
timestamp
timestamp[s]date
2013-03-13 20:45:00
2026-04-11 07:48:46
huggingface/transformers
449533af73874470e914a203391635e04ac2ffc8
e691f84412563b6abca098f3e044980725d8daa3
Add language specifiers to code blocks of markdown files (#41114) * Add language specifiers to code blocks of markdown files Signed-off-by: Yuanyuan Chen <cyyever@outlook.com> * Update docs/source/en/model_doc/qwen3_omni_moe.md Co-authored-by: Steven Liu <59462357+stevhliu@users.noreply.github.com> * Update docs/s...
[ { "path": "docs/source/en/chat_templating_multimodal.md", "patch": "@@ -56,7 +56,7 @@ out = pipe(text=messages, max_new_tokens=128)\n print(out[0]['generated_text'][-1]['content'])\n ```\n \n-```\n+```text\n Ahoy, me hearty! These be two feline friends, likely some tabby cats, taking a siesta on a cozy pink...
2025-09-25T17:29:57
vuejs/vue
ff178ccc7eb9a00958240059078c7651359fce3d
8823fcc7a434f5eaea72e7a8c3a1e8f8c32f617a
fix directive rawName generation for raw render functions (fix #3930)
[ { "path": "src/core/vdom/modules/directives.js", "patch": "@@ -90,23 +90,17 @@ function normalizeDirectives (\n let i, dir\n for (i = 0; i < dirs.length; i++) {\n dir = dirs[i]\n- res[getRawDirName(dir)] = dir\n if (!dir.modifiers) {\n dir.modifiers = emptyModifiers\n }\n+ res[ge...
2016-10-13T07:18:21
ggml-org/llama.cpp
3de008208b9b8a33f49f979097a99b4d59e6e521
69db8a52e6dd0db81ec05c581150cc1e43b8ac46
fix: resolve unsigned int initialization warning for n_dims/size in gguf.cpp (#15754)
[ { "path": "ggml/src/gguf.cpp", "patch": "@@ -273,7 +273,7 @@ struct gguf_reader {\n }\n \n bool read(std::string & dst) const {\n- uint64_t size = -1;\n+ uint64_t size = 0;\n if (!read(size)) {\n return false;\n }\n@@ -523,7 +523,7 @@ struct gguf_context * g...
2025-09-02T19:27:30
huggingface/transformers
e691f84412563b6abca098f3e044980725d8daa3
e54bb62a73d2da84f973df17d2604338760b702f
Force new vision models addition to include a fast image processor (#40802) * add test * fix test and change cutoff date * Add documentation to test
[ { "path": "tests/test_image_processing_common.py", "patch": "@@ -16,11 +16,13 @@\n import json\n import os\n import pathlib\n+import subprocess\n import tempfile\n import time\n import unittest\n import warnings\n from copy import deepcopy\n+from datetime import datetime\n \n import httpx\n import numpy as ...
2025-09-25T15:58:18
denoland/deno
b6f567946baf9e0b7d8ac186ddd4364d24b9dc7a
d4e149e2eed94a1eb2052050383618111da3002d
test: fix `utimeSyncFileSuccess` in `js_unit_test::worker_test` (#31273) `../testdata/workers/worker_types.ts` didn't even exist, causing the test to fail. See #30770 Co-authored-by: David Sherret <dsherret@users.noreply.github.com>
[ { "path": "tests/unit/worker_test.ts", "patch": "@@ -15,7 +15,7 @@ Deno.test(\n { permissions: { read: true } },\n function utimeSyncFileSuccess() {\n const w = new Worker(\n- resolveWorker(\"worker_types.ts\"),\n+ resolveWorker(\"test_worker.js\"),\n { type: \"module\" },\n );\n...
2025-11-17T14:35:27
vuejs/vue
6e96a657d8c96d48f1ba6ad051aae1eff0d58c73
6ab10c0559094b6870b5c6601ae526ee579b796b
adjust component destroy logic (really fix #3882)
[ { "path": "src/core/instance/lifecycle.js", "patch": "@@ -187,6 +187,8 @@ export function lifecycleMixin (Vue: Class<Component>) {\n if (vm.$el) {\n vm.$el.__vue__ = null\n }\n+ // invoke destroy hooks on current rendered tree\n+ vm.__patch__(vm._vnode, null)\n }\n }\n ", "addition...
2016-10-12T21:43:08
ggml-org/llama.cpp
0a2a3841e8ebc570da343e8cf58a21c1010b41e7
9961d244f2df6baf40af2f1ddc0927f8d91578c8
vulkan: fix shaders gen when no integer dot is available (#15740)
[ { "path": "ggml/src/ggml-vulkan/vulkan-shaders/vulkan-shaders-gen.cpp", "patch": "@@ -854,7 +854,13 @@ void write_output_files() {\n fputs(len.c_str(), src);\n }\n \n- for (const std::string& btype : {\"f16\", \"f32\", \"q8_1\"}) {\n+ std::vector<std::string> btypes = {\"f16\", \"f32\"};\n...
2025-09-02T14:02:26
denoland/deno
d4e149e2eed94a1eb2052050383618111da3002d
05395f375321fd850facfa849a45a1bc32bbe847
ci: add ability to trigger AI issue triage manually (#31260) Should fix permission error too. --------- Co-authored-by: Claude <noreply@anthropic.com>
[ { "path": ".github/workflows/issue_triage.yml", "patch": "@@ -3,25 +3,33 @@ name: AI Issue Triage\n on:\n issues:\n types: [opened]\n+ workflow_dispatch:\n+ inputs:\n+ issue_number:\n+ description: 'Issue number to triage'\n+ required: true\n+ type: number\n \n jobs:\n ...
2025-11-17T14:20:03
vuejs/vue
6ab10c0559094b6870b5c6601ae526ee579b796b
ea39d9f6b8220d24320fdef08070a01b94f241c6
fix v-for list auto-keying with nested <template> (fix #3913)
[ { "path": "src/compiler/optimizer.js", "patch": "@@ -75,6 +75,20 @@ function isStatic (node: ASTNode): boolean {\n !node.if && !node.for && // not v-if or v-for or v-else\n !isBuiltInTag(node.tag) && // not a built-in\n isPlatformReservedTag(node.tag) && // not a component\n+ !isDirectChildOf...
2016-10-12T21:12:12
huggingface/transformers
e54bb62a73d2da84f973df17d2604338760b702f
6dc9ed87a02db8b4ecc26a5e98596cd2bba380b5
Simplify and improve model loading logic (#41103) * remove unexpected keys from inputs (they have nothing to do there) * remove input * simplify a lot init * fix * fix check for non-persistent buffer * revert because too many old and bad models... * remove comment * type hint * make it a real test * remove mo...
[ { "path": "conftest.py", "patch": "@@ -64,8 +64,7 @@\n \"test_load_save_without_tied_weights\",\n \"test_tied_weights_keys\",\n \"test_model_weights_reload_no_missing_tied_weights\",\n- \"test_mismatched_shapes_have_properly_initialized_weights\",\n- \"test_matched_shapes_have_loaded_weigh...
2025-09-25T15:28:27
ggml-org/llama.cpp
25f1045f07cf0daf667d63e35618842e3174a8c7
97669e40735d08db65ef094a8faae8e8411a97db
vulkan: Fix macro parameter order for f32 matmul shaders (#15716)
[ { "path": "ggml/src/ggml-vulkan/ggml-vulkan.cpp", "patch": "@@ -2778,11 +2778,11 @@ static void ggml_vk_load_shaders(vk_device& device) {\n // Create 6 variants, {s,m,l}x{unaligned,aligned}\n #define CREATE_MM(TYPE, PIPELINE_NAME, NAMELC, F16ACC, WG_DENOMS, WARPTILE, PUSHCONST, PARAMCOUNT, ID, REQSU...
2025-09-02T06:37:01
denoland/deno
2f475fce496f675ed89bc6298f5ce32d9b8030cb
e0f04c6aea2972866155f6c99773f1af1cad58f4
ci: use windows-2022 image for 'promote_to_release' workflow (#31286) Also changes code-signing step to not cache dependencies, which should fix the problem with Azure Codesigning returning error because of missing deps.
[ { "path": ".github/workflows/promote_to_release.yml", "patch": "@@ -18,7 +18,7 @@ jobs:\n # Handle Windows binary patching and re-signing in a separate job\n promote-to-release-windows:\n name: Promote Windows to Release\n- runs-on: windows-latest\n+ runs-on: windows-2022\n if: github.repo...
2025-11-17T08:30:46
vuejs/vue
ea39d9f6b8220d24320fdef08070a01b94f241c6
5d0999ac375f477a9f2746ea746081d07ee60c64
fix static node v-for nested check
[ { "path": "src/compiler/optimizer.js", "patch": "@@ -57,7 +57,7 @@ function markStaticRoots (node: ASTNode, isInFor: boolean) {\n }\n if (node.children) {\n for (let i = 0, l = node.children.length; i < l; i++) {\n- markStaticRoots(node.children[i], !!node.for)\n+ markStaticRoots...
2016-10-12T20:31:56
huggingface/transformers
6dc9ed87a02db8b4ecc26a5e98596cd2bba380b5
a579de7f5e00a9fdb1e9828aa3ab78385959f231
Fix format of compressed_tensors.md (#41155) * Fix table format Signed-off-by: Yuanyuan Chen <cyyever@outlook.com> * Fix format Signed-off-by: Yuanyuan Chen <cyyever@outlook.com> --------- Signed-off-by: Yuanyuan Chen <cyyever@outlook.com>
[ { "path": "docs/source/en/quantization/compressed_tensors.md", "patch": "@@ -65,11 +65,11 @@ print(f\"{mem_params/2**30:.4f} GB\")\n \n ## Model checkpoint\n \n-compressed-tensor models are defined through its configuration entry. The following example is taken from the [nm-testing/Meta-Llama-3.1-8B-Instruc...
2025-09-25T14:50:15
ggml-org/llama.cpp
2f853687b3bce15e143a22f678d1715060fd606c
ef2af57ddf04ab367f6ba6e8ed100fc56785e4b7
CANN: Support eager execution mode under ACL graph compilation (#15712) * [CANN] Support eager execution mode under ACL graph compilation Add support for running operators in eager mode while ACL graph compilation is enabled. This allows bypassing graph execution and directly submitting ops, which is useful for debug...
[ { "path": "docs/backend/CANN.md", "patch": "@@ -314,3 +314,7 @@ Controls automatic cleanup of the memory pool. This option is only effective whe\n \n Converting the matmul weight format from ND to NZ can significantly improve performance on the 310I DUO NPU.\n \n+### GGML_CANN_DISABLE_ACL_GRAPH\n+\n+When th...
2025-09-02T06:07:48
denoland/deno
e0f04c6aea2972866155f6c99773f1af1cad58f4
f48bd0487759c759be48d55e618f3289196caad7
build(deps): update aws-lc-rs (#31307) This pulls some build improvements and fixes, including https://github.com/aws/aws-lc/pull/2381/
[ { "path": "Cargo.lock", "patch": "@@ -373,28 +373,26 @@ checksum = \"0c4b4d0bd25bd0b74681c0ad21497610ce1b7c91b1022cd21c80c6fbdd9476b0\"\n \n [[package]]\n name = \"aws-lc-rs\"\n-version = \"1.12.4\"\n+version = \"1.13.1\"\n source = \"registry+https://github.com/rust-lang/crates.io-index\"\n-checksum = \"4c...
2025-11-17T08:24:38
vuejs/vue
ceab0b71d0dd8247220564b2a651f7bea0a796d6
7ca58b6cdf985da1751c97290fb1e2fc9fb08f41
fix functional components that return string or nothing (fix #3919)
[ { "path": "src/core/vdom/create-component.js", "patch": "@@ -113,9 +113,11 @@ function createFunctionalComponent (\n slots: () => resolveSlots(children, context)\n }\n )\n- vnode.functionalContext = context\n- if (data.slot) {\n- (vnode.data || (vnode.data = {})).slot = data.slot\n+ if (vn...
2016-10-12T17:31:39
ggml-org/llama.cpp
d4d8dbe383e8b9600cbe8b42016e3a4529b51219
35a42edac84690990a75726898d975cd08d220c0
vulkan: use memory budget extension to read memory usage (#15545) * vulkan: use memory budget extension to read memory usage * fix: formatting and names * formatting * fix: detect and cache memory budget extension availability on init * fix: read `budgetprops.heapBudget` instead of `heap.size` when memory budget e...
[ { "path": "ggml/src/ggml-vulkan/ggml-vulkan.cpp", "patch": "@@ -1370,6 +1370,7 @@ struct vk_instance_t {\n PFN_vkCmdInsertDebugUtilsLabelEXT pfn_vkCmdInsertDebugUtilsLabelEXT = {};\n \n std::vector<size_t> device_indices;\n+ std::vector<bool> device_supports_membudget;\n vk_device devices...
2025-09-01T19:17:42
huggingface/transformers
a579de7f5e00a9fdb1e9828aa3ab78385959f231
1dd22a234cdbec840d139871720447baf809158b
Add Parakeet (#39062) * first commit Signed-off-by: nithinraok <nithinrao.koluguri@gmail.com> * update to handle masking for bs>1 Signed-off-by: nithinraok <nithinrao.koluguri@gmail.com> * Add tests and docs Signed-off-by: nithinraok <nithinrao.koluguri@gmail.com> * update model ids Signed-off-by: nithinraok <n...
[ { "path": "docs/source/en/_toctree.yml", "patch": "@@ -935,6 +935,8 @@\n title: MusicGen\n - local: model_doc/musicgen_melody\n title: MusicGen Melody\n+ - local: model_doc/parakeet\n+ title: Parakeet\n - local: model_doc/pop2piano\n title: Pop2Piano\n -...
2025-09-25T13:52:24
denoland/deno
f48bd0487759c759be48d55e618f3289196caad7
863abe816e2fac2863ed755321e09311ea61d592
fix(ext/node): sqlite.DatabaseSync explicit resource management compatibility (#31311) Allows https://github.com/nodejs/node/blob/v24.2.0/test/parallel/test-sqlite-database-sync-dispose.js to pass
[ { "path": "ext/node/polyfills/sqlite.ts", "patch": "@@ -9,8 +9,9 @@ import {\n import { Buffer } from \"node:buffer\";\n \n const {\n- ObjectDefineProperty,\n+ ObjectDefineProperties,\n SymbolFor,\n+ SymbolDispose,\n } = primordials;\n \n interface BackupOptions {\n@@ -103,11 +104,26 @@ export const co...
2025-11-17T07:58:49
ggml-org/llama.cpp
02c1813517412f3e00aa6ca7c0273fea64edb492
77dee9de97be75b7143a213bc48893e0c0b29af7
Vulkan: Add Integer Dot Product mul_mat_vec shader for legacy quants (#14903) * vulkan: Add Integer Dot Product mul_mat_vec shader for legacy quants * vulkan: use subgroup operations for quantize_q8_1 shader * vulkan: add q8_1_x4 type with 128-bit alignment, use in mul_mat_vecq shader * vulkan: use q8_1_x4 blocks i...
[ { "path": "ggml/src/ggml-vulkan/ggml-vulkan.cpp", "patch": "@@ -360,6 +360,13 @@ struct vk_fa_pipeline_state {\n }\n };\n \n+enum shader_reduction_mode {\n+ SHADER_REDUCTION_MODE_SHMEM,\n+ SHADER_REDUCTION_MODE_HYBRID,\n+ SHADER_REDUCTION_MODE_SUBGROUP,\n+ SHADER_REDUCTION_MODE_COUNT,\n+};\n...
2025-09-01T14:19:07
huggingface/transformers
05fb90c96903cf0e3d8376316a23d7401969690b
44682e71314f004c8cf157f76e6956e58f6f730f
Fix single quotes in markdown (#41154) Fix typos Signed-off-by: Yuanyuan Chen <cyyever@outlook.com>
[ { "path": "docs/TRANSLATING.md", "patch": "@@ -50,7 +50,7 @@ Begin translating the text!\n \n 1. Start with the `_toctree.yml` file that corresponds to your documentation chapter. This file is essential for rendering the table of contents on the website.\n \n- - If the `_toctree.yml` file doesn’t exist f...
2025-09-25T13:03:26
denoland/deno
5951cba6e78d47b279b807293ad57b1aa5ac1c2d
e7ef895d21e4ff6df466fb74cd19d84f599bab3d
chore: fix patchver on windows (#31303)
[ { "path": "tools/release/promote_to_release.ts", "patch": "@@ -5,7 +5,7 @@\n \n import { $ } from \"jsr:@david/dax@0.41.0\";\n import { gray } from \"jsr:@std/fmt@1/colors\";\n-import { patchver } from \"jsr:@deno/patchver@0.3.0\";\n+import { patchver } from \"jsr:@deno/patchver@0.4.0\";\n \n const SUPPORTE...
2025-11-17T07:41:20
ggml-org/llama.cpp
b66df9d9c942254d03209186ef24ed7c994a576e
b9382c3877c6067feccf182efe9449a2d1cb24c7
CUDA: fix build error from ambiguous __half conversions in conv2d (#15690) * CUDA: fix build error from ambiguous __half conversions in conv2d Building conv2d with half precision failed because `__half` defines multiple implicit conversion operators (to float, int, short, etc.), causing ambiguous overload resolution ...
[ { "path": "ggml/src/ggml-cuda/conv2d.cu", "patch": "@@ -1,4 +1,5 @@\n #include \"conv2d.cuh\"\n+#include \"convert.cuh\"\n \n struct conv_params {\n const int64_t IW, IH;\n@@ -94,8 +95,8 @@ static __global__ void conv2d_kernel(const float * __restrict__ input,\n const int64_t in_x = calc...
2025-09-01T01:25:06
huggingface/transformers
44682e71314f004c8cf157f76e6956e58f6f730f
750dd2a401b803ba5542ed15251c7c743b2fd85b
Adapt and test huggingface_hub v1.0.0 (#40889) * Adapt and test huggingface_hub v1.0.0.rc0 * forgot to bump hfh * bump * code quality * code quality * relax dependency table * fix has_file * install hfh 1.0.0.rc0 in circle ci jobs * repostiryo * push to hub now returns a commit url * catch HfHubHTTPError * ...
[ { "path": "setup.py", "patch": "@@ -114,12 +114,12 @@\n \"GitPython<3.1.19\",\n \"hf-doc-builder>=0.3.0\",\n \"hf_xet\",\n- \"huggingface-hub>=0.34.0,<1.0\",\n+ \"huggingface-hub==1.0.0.rc1\",\n \"importlib_metadata\",\n \"ipadic>=1.0.0,<2.0\",\n \"jinja2>=3.1.0\",\n \"kenl...
2025-09-25T11:13:50
vuejs/vue
a9417e4e4fcb91d445c15d79b6eec684d7e5c9c7
443ef1c26c299856709ff59aa2f9e7816fbd7908
select change event fix (#3922) * if select binding not changed, then needRest should be set to false, and no change event should be emitted * update code style
[ { "path": "src/platforms/web/runtime/directives/model.js", "patch": "@@ -60,7 +60,7 @@ export default {\n // option in the DOM.\n const needReset = el.multiple\n ? binding.value.some(v => hasNoMatchingOption(v, el.options))\n- : hasNoMatchingOption(binding.value, el.options)\n+ ...
2016-10-12T17:26:42
denoland/deno
e7ef895d21e4ff6df466fb74cd19d84f599bab3d
1404815e100956e6db84dd80f888f4df949bc06c
fix(lsp): `organizeImports` without resolving specifiers (#31230)
[ { "path": "cli/lsp/language_server.rs", "patch": "@@ -2347,21 +2347,10 @@ impl Inner {\n })?;\n \n if !organize_imports_edit.is_empty() {\n- let mut changes_with_modules = IndexMap::new();\n- changes_with_modules.extend(\n- fix_ts_import_changes(&organize_imports_edit, &...
2025-11-17T06:57:54
ggml-org/llama.cpp
3dc7397a2799bdc07bccf637ab7ae5a1e786d1a4
e92d53b29e393fc4c0f9f1f7c3fe651be8d36faa
CANN: fix RoPE cache issue on multi-device (#15629) * CANN: fix RoPE cache issue on multi-device RoPE cache only needs to be computed once per token. However, in multi-device scenarios, not every device starts computation from layer 0, which may lead to unallocated memory issues and precision errors. This commit rec...
[ { "path": "ggml/src/ggml-cann/aclnn_ops.cpp", "patch": "@@ -964,8 +964,8 @@ void ggml_cann_rms_norm(ggml_backend_cann_context& ctx, ggml_tensor* dst) {\n }\n aclTensor* acl_gamma = get_f32_cache_acl_tensor(\n ctx,\n- &ctx.f32_one_cache,\n- ctx.f32_one_cache_element,\n+ &...
2025-09-01T00:57:00
huggingface/transformers
750dd2a401b803ba5542ed15251c7c743b2fd85b
7258ea44bc0c0a425a468f66f8559d1de8c4126d
Fix: align Qwen2.5-VL inference rope index with training by passing s… (#41153) Fix: align Qwen2.5-VL inference rope index with training by passing second_per_grid_ts
[ { "path": "src/transformers/models/qwen2_5_vl/modeling_qwen2_5_vl.py", "patch": "@@ -1558,6 +1558,7 @@ def prepare_inputs_for_generation(\n model_inputs.get(\"input_ids\", None),\n image_grid_thw=image_grid_thw,\n video_grid_thw=video_grid_thw,\n+ ...
2025-09-25T10:33:46
vuejs/vue
864ef21a7d679697b5e135d2b81aa71b495b2656
03ea9f0b57467637c67adcd97139ed61dc218d55
fix deeply nested keep-alive components not being destroyed (fix #3882)
[ { "path": "src/core/vdom/patch.js", "patch": "@@ -202,7 +202,10 @@ export function createPatchFunction (backend) {\n if (isDef(i = data.hook) && isDef(i = i.destroy)) i(vnode)\n for (i = 0; i < cbs.destroy.length; ++i) cbs.destroy[i](vnode)\n }\n- if (isDef(i = vnode.child) && !data.keepA...
2016-10-12T03:58:53
denoland/deno
1404815e100956e6db84dd80f888f4df949bc06c
4bf2ad3be7b40b99094e12eb309a730c7c529cd4
fix(deps): use windows-sys for all windows targets (#31308) there are `*-pc-windows-gnullvm` target, which are not covered by the previous condition. other packages are already using this
[ { "path": "runtime/subprocess_windows/Cargo.toml", "patch": "@@ -14,9 +14,7 @@ fastrand = \"2.3.0\"\n futures-channel = \"0.3.31\"\n libc = \"0.2.172\"\n \n-[target.x86_64-pc-windows-gnu.dependencies]\n-windows-sys = { version = \"0.59.0\", features = [\"Win32_Security\", \"Win32_System_JobObjects\", \"Win3...
2025-11-16T15:37:08
ggml-org/llama.cpp
e92d53b29e393fc4c0f9f1f7c3fe651be8d36faa
0d161f021aa33ec0e90cce96f5d1a88925557327
sampling : optimize samplers by reusing bucket sort (#15665) * sampling : optimize sorting using bucket sort in more places ggml-ci * sampling : do not sort in dist sampler ggml-ci * sampling : avoid heap allocations for sort buffers ggml-ci * common : add option to sort sampling candidates by probability ggml-...
[ { "path": "common/sampling.cpp", "patch": "@@ -426,8 +426,29 @@ uint32_t common_sampler_get_seed(const struct common_sampler * gsmpl) {\n \n // helpers\n \n-llama_token_data_array * common_sampler_get_candidates(struct common_sampler * gsmpl) {\n- return &gsmpl->cur_p;\n+llama_token_data_array * common_s...
2025-08-31T17:41:02
huggingface/transformers
7258ea44bc0c0a425a468f66f8559d1de8c4126d
2c4caa19e79ec8b6e2d401d58bdc63088e453600
Fix loading logic flaw with regards to unexpected and missing keys (#40850) * Unexpected keys should be ignored at load with device map * remove them all * fix logic flaw * fix * simplify * style * fix * revert caching allocator change * add other test * add nice doc --------- Co-authored-by: Cyril Vallez <...
[ { "path": "src/transformers/modeling_utils.py", "patch": "@@ -738,8 +738,6 @@ def _load_state_dict_into_meta_model(\n file_pointer = safe_open(shard_file, framework=\"pt\", device=tensor_device)\n \n for param_name, empty_param in state_dict.items():\n- if param_name not in expected_keys:...
2025-09-24T14:44:42
vuejs/vue
03ea9f0b57467637c67adcd97139ed61dc218d55
7570a3c566969bbb5afb5bfa2c2c068aecae379c
fix flow
[ { "path": "flow/compiler.js", "patch": "@@ -52,6 +52,7 @@ declare type ASTElementHandlers = {\n \n declare type ASTDirective = {\n name: string;\n+ rawName: string;\n value: string;\n arg: ?string;\n modifiers: ?{ [key: string]: true };", "additions": 1, "deletions": 0, "language": "Jav...
2016-10-12T00:50:28
ggml-org/llama.cpp
0d161f021aa33ec0e90cce96f5d1a88925557327
4efd5a83163ff383285b3a4c2106feabf5c69557
server : enable /slots by default and make it secure (#15630) * server : enable /slots by default and make it secure ggml-ci * server : fix tests to pass `--no-slots` when necessary * server : extend /props with info about enabled endpoints
[ { "path": "common/arg.cpp", "patch": "@@ -2962,20 +2962,20 @@ common_params_context common_params_parser_init(common_params & params, llama_ex\n params.endpoint_metrics = true;\n }\n ).set_examples({LLAMA_EXAMPLE_SERVER}).set_env(\"LLAMA_ARG_ENDPOINT_METRICS\"));\n- add_opt(common...
2025-08-31T17:11:58
denoland/deno
4bf2ad3be7b40b99094e12eb309a730c7c529cd4
96434a1d390d105514b8bf6f8ac0fc135e8f8f7a
fix: skip doing npm resolution in more cases (#31305) There was a bug that was causing npm resolution to occur due to: * https://github.com/denoland/deno_semver/pull/49 Also includes: * https://github.com/denoland/deno_semver/pull/45
[ { "path": "Cargo.lock", "patch": "@@ -2876,9 +2876,9 @@ dependencies = [\n \n [[package]]\n name = \"deno_semver\"\n-version = \"0.9.0\"\n+version = \"0.9.1\"\n source = \"registry+https://github.com/rust-lang/crates.io-index\"\n-checksum = \"2625b7107cc3f61a462886d5fa77c23e063c1fd15b90e3d5ee2646e9f6178d55\...
2025-11-15T22:50:58
huggingface/transformers
6d1875924c9f15eb4d2d491c9f37c6dd7455cf06
3ca43d34b197d10e79c00f7651daa6e0a6d3504f
Fixed loading LongT5 from legacy checkpoints (#40724) * Fixed loading LongT5 from legacy checkpoints * Adapted the fix to work with missing lm_head
[ { "path": "src/transformers/models/longt5/modeling_longt5.py", "patch": "@@ -1267,6 +1267,36 @@ def dummy_inputs(self):\n }\n return dummy_inputs\n \n+ def _try_load_missing_tied_module(self, key):\n+ module = self\n+ if key.endswith(\".weight\"):\n+ key = key[: -...
2025-09-24T12:13:18
vuejs/vue
7570a3c566969bbb5afb5bfa2c2c068aecae379c
1fa3844dc26745b4cb855b0934bd1b132ba33d9b
test for directive refactor (fix #3848)
[ { "path": "src/core/vdom/helpers.js", "patch": "@@ -68,16 +68,17 @@ export function getFirstComponentChild (children: ?Array<any>) {\n export function mergeVNodeHook (def: Object, hookKey: string, hook: Function, key: string) {\n key = key + hookKey\n const injectedHash = def.__injected || (def.__inject...
2016-10-12T00:49:10
denoland/deno
96434a1d390d105514b8bf6f8ac0fc135e8f8f7a
00f1eeb8b00e854d610e8b8f4c545e2822ff6c3c
fix(ext/web): Event dispatch should continue after reporting exception (#31297) https://dom.spec.whatwg.org/#concept-event-listener-inner-invoke --------- Signed-off-by: snek <snek@deno.com>
[ { "path": "ext/web/02_event.js", "patch": "@@ -772,16 +772,20 @@ function innerInvokeEventListeners(\n setInPassiveListener(eventImpl, true);\n }\n \n- if (typeof listener.callback === \"object\") {\n- if (typeof listener.callback.handleEvent === \"function\") {\n- listener.callback...
2025-11-15T17:45:29
ggml-org/llama.cpp
4efd5a83163ff383285b3a4c2106feabf5c69557
274966226f87f301ac132da898280ca3142b60e5
metal : fix checks for available FA kernels (#15700) * metal : fix checks for available FA kernels ggml-ci * cont : fix comment [no ci]
[ { "path": "ggml/src/ggml-metal/ggml-metal.m", "patch": "@@ -523,13 +523,6 @@ static void ggml_backend_metal_device_rel(struct ggml_backend_metal_device_conte\n GGML_METAL_KERNEL_TYPE_FLASH_ATTN_EXT_Q8_0_HK192_HV128,\n GGML_METAL_KERNEL_TYPE_FLASH_ATTN_EXT_Q8_0_H256,\n GGML_METAL_KERNEL_TYPE_FLAS...
2025-08-31T16:43:30
huggingface/transformers
3ca43d34b197d10e79c00f7651daa6e0a6d3504f
b33cb700978bbd9d5152fdc650d022ee11619347
Fixed MXFP4 model storage issue (#41118)
[ { "path": "src/transformers/quantizers/quantizer_mxfp4.py", "patch": "@@ -379,7 +379,7 @@ def update_param_name(self, param_name: str) -> str:\n return param_name.replace(\"down_proj\", \"down_proj_blocks\")\n return param_name\n \n- def get_state_dict_and_metadata(self, model):\n...
2025-09-24T12:11:51
vuejs/vue
5300ef7819e12d8b114d808ea2ac85e36a6fff5c
d0cfd549ba24edc7dced17ef7b8f410c4ea197f0
fix style module removing styles with value 0 on update (fix #3905)
[ { "path": "src/platforms/web/runtime/modules/style.js", "patch": "@@ -49,7 +49,7 @@ function updateStyle (oldVnode: VNodeWithData, vnode: VNodeWithData) {\n }\n \n for (name in oldStyle) {\n- if (!style[name]) {\n+ if (style[name] == null) {\n el.style[normalize(name)] = ''\n }\n }", ...
2016-10-11T17:05:34
ggml-org/llama.cpp
274966226f87f301ac132da898280ca3142b60e5
9777032dccd67bdc7785aeab7497014a8be8dacc
llama : fix fattn reserve call n_seqs parameter (#15699) ggml-ci
[ { "path": "src/llama-context.cpp", "patch": "@@ -281,9 +281,15 @@ llama_context::llama_context(\n }\n \n cross.v_embd.clear();\n+\n+ const uint32_t n_seqs = cparams.kv_unified ? 1 : cparams.n_seq_max;\n+ const uint32_t n_tokens = std::min(cparams.n_ctx, cparams.n_ubatch);\n+\n+...
2025-08-31T15:47:05
denoland/deno
b0cfbf53d3984a8e4aa26ca4f24d48f0df54e7c8
ffe207a859a85b6eb0079b137916ed12c0efbfce
fix(ext/node): Add sqlite `setAllowUnknownNamedParameters` option (#31202) Adds [statement.setAllowUnknownNamedParameters(enabled)](https://nodejs.org/api/sqlite.html#statementsetallowunknownnamedparametersenabled) to `node:sqlite`. Closes #31196
[ { "path": "ext/node/ops/sqlite/database.rs", "patch": "@@ -569,6 +569,7 @@ impl DatabaseSync {\n statements: Rc::clone(&self.statements),\n use_big_ints: Cell::new(false),\n allow_bare_named_params: Cell::new(true),\n+ allow_unknown_named_params: Cell::new(false),\n is_iter_fini...
2025-11-14T10:30:03
vuejs/vue
d0cfd549ba24edc7dced17ef7b8f410c4ea197f0
8bb1e58df06f6ac41f8dfd00c91ec75f88091530
Revert "fix select multiple first option auto-selected in Chrome/FF (fix #3852)" This reverts commit f9bef75a3425213d2f1ff3bc7fb27322617bc233.
[ { "path": "src/platforms/web/runtime/modules/attrs.js", "patch": "@@ -68,15 +68,6 @@ function setAttr (el: Element, key: string, value: any) {\n }\n \n export default {\n- create: function initAttrs (_: VNodeWithData, vnode: VNodeWithData) {\n- updateAttrs(_, vnode)\n- // #3852: if the \"multiple\" a...
2016-10-11T16:53:51
ggml-org/llama.cpp
e81b8e4b7f5ab870836fad26d154a7507b341b36
38ad381f9f5d4dd368a96d844fb19cf501ed9d22
llama: use FA + max. GPU layers by default (#15434) * llama: use max. GPU layers by default, auto -fa * ggml-backend: abort instead of segfault
[ { "path": "common/arg.cpp", "patch": "@@ -1545,10 +1545,18 @@ common_params_context common_params_parser_init(common_params & params, llama_ex\n }\n ).set_examples({LLAMA_EXAMPLE_IMATRIX, LLAMA_EXAMPLE_PERPLEXITY, LLAMA_EXAMPLE_RETRIEVAL}));\n add_opt(common_arg(\n- {\"-fa\", \"--flas...
2025-08-30T14:32:10
denoland/deno
ffe207a859a85b6eb0079b137916ed12c0efbfce
de72003747692fc64628890efe7f22ba4cca58ac
fix(ext/node): FileHandle compatibility (#31164) Towards #29972 Tries to reland #31094 that got reverted on #31103 due to CI test failures. This PR differs by fixing the `[kUnref]` method to close resource ID correctly. Allows the following tests to pass: - https://github.com/nodejs/node/blob/v24.2.0/test/parallel/...
[ { "path": "ext/node/polyfills/_fs/_fs_fchmod.ts", "patch": "@@ -10,6 +10,7 @@ import {\n } from \"ext:deno_node/internal/validators.mjs\";\n import { op_fs_fchmod_async, op_fs_fchmod_sync } from \"ext:core/ops\";\n import { primordials } from \"ext:core/mod.js\";\n+import { promisify } from \"ext:deno_node/...
2025-11-14T05:17:45
huggingface/transformers
b33cb700978bbd9d5152fdc650d022ee11619347
b0c7034d5862d99b6040fcedb437bc1cbd0220cc
🚨Refactor: Update text2text generation pipelines to use max_new_tokens… (#40928) * Refactor: Update text2text generation pipelines to use max_new_tokens and resolve max_length warning * docs(text2text_generation): 更新参数注释以反映现代生成实践 将max_length参数注释更新为max_new_tokens,以符合现代生成实践中指定生成新token数量的标准做法 * refactor(text2text_gen...
[ { "path": "src/transformers/pipelines/text2text_generation.py", "patch": "@@ -123,7 +123,7 @@ def _sanitize_parameters(\n \n return preprocess_params, forward_params, postprocess_params\n \n- def check_inputs(self, input_length: int, min_length: int, max_length: int):\n+ def check_inputs(self,...
2025-09-24T11:54:55
vuejs/vue
8bb1e58df06f6ac41f8dfd00c91ec75f88091530
71ef9d68f2e8f1cddff70ea42b178adf31454e29
fix multiple select render (#3908) * fix multiple select render. The mutliple attribute of select dosen't apply at first, so the mutli selected option dosen't work when patching * keep the vnode.data the same as before
[ { "path": "src/core/vdom/patch.js", "patch": "@@ -115,7 +115,7 @@ export function createPatchFunction (backend) {\n }\n vnode.elm = vnode.ns\n ? nodeOps.createElementNS(vnode.ns, tag)\n- : nodeOps.createElement(tag)\n+ : nodeOps.createElement(tag, vnode)\n setScope(vn...
2016-10-11T16:53:30
huggingface/transformers
04a0bb569c674c627e5658e1f48d16312bb25bab
071c7b142321ae31b621ccd8b4446d4a39fa3a58
Fix broken `` expressions in markdown files (#41113) Fix broken expressions in markdown files Signed-off-by: Yuanyuan Chen <cyyever@outlook.com>
[ { "path": "docs/source/en/model_doc/llama3.md", "patch": "@@ -60,7 +60,7 @@ Tips:\n \n - Weights for the Llama3 models can be obtained by filling out [this form](https://ai.meta.com/resources/models-and-libraries/llama-downloads/)\n - The architecture is exactly the same as Llama2.\n-- The tokenizer is a BP...
2025-09-24T11:34:12
denoland/deno
de72003747692fc64628890efe7f22ba4cca58ac
67ee2af25011bd14b08476a77e8dc272858407ae
fix(tunnel): misc fixes (#30968)
[ { "path": "cli/main.rs", "patch": "@@ -715,19 +715,12 @@ async fn resolve_flags_and_init(\n .map(|files| files.iter().map(PathBuf::from).collect());\n load_env_variables_from_env_files(env_file_paths.as_ref(), flags.log_level);\n \n- if deno_lib::args::has_flag_env_var(\"DENO_CONNECTED\")\n- && ma...
2025-11-14T05:10:00
vuejs/vue
cc4c0669890206f14fd6aff5f7d59327d1e3f2e5
484e538df8e959bc6026c8b83ab63815ad23ef43
fix coverage
[ { "path": "src/core/util/props.js", "patch": "@@ -162,15 +162,14 @@ function getType (fn) {\n }\n \n function isBooleanType (fn) {\n- const isBoolean = (fnItem) => getType(fnItem) === 'Boolean'\n-\n if (!Array.isArray(fn)) {\n- return isBoolean(fn)\n+ return getType(fn) === 'Boolean'\n }\n for ...
2016-10-11T03:25:24
huggingface/transformers
071c7b142321ae31b621ccd8b4446d4a39fa3a58
80f20e0ff8786087bb581fd4ce1eba2d69d62352
Fix the error where a keyword argument appearing before *args (#41099) Signed-off-by: Yuanyuan Chen <cyyever@outlook.com>
[ { "path": "src/transformers/commands/add_new_model_like.py", "patch": "@@ -755,7 +755,7 @@ def register_subcommand(parser: ArgumentParser):\n )\n add_new_model_like_parser.set_defaults(func=add_new_model_like_command_factory)\n \n- def __init__(self, path_to_repo=None, *args):\n+ def _...
2025-09-24T11:27:37
denoland/deno
67ee2af25011bd14b08476a77e8dc272858407ae
138b2e0e62d07a8786385cae46ac179afbf9973f
fix(ext/signals): don't run exit hooks at non-exit times (#31269) when we changed the otel exit handler to call shutdown instead of flush, it exposed another bug where we are calling exit handlers multiple times for the 3 signals we have defined. this meant that we would shut down otel before the program finished runn...
[ { "path": "ext/net/tunnel.rs", "patch": "@@ -48,15 +48,15 @@ pub fn disable_before_exit() {\n }\n \n pub fn before_exit() {\n- if let Some(tunnel) = get_tunnel() {\n- log::trace!(\"deno_net::tunnel::before_exit >\");\n+ log::trace!(\"deno_net::tunnel::before_exit >\");\n \n+ if let Some(tunnel) = get_...
2025-11-13T22:15:37
vuejs/vue
484e538df8e959bc6026c8b83ab63815ad23ef43
5b4b9269a52548034ff72c0fbd1cb20d897647f8
fix lint
[ { "path": "src/platforms/web/runtime/directives/model.js", "patch": "@@ -4,7 +4,7 @@\n */\n \n import { looseEqual, looseIndexOf } from 'shared/util'\n-import { warn, nextTick, isAndroid, isIE9, isIE, isEdge } from 'core/util/index'\n+import { warn, isAndroid, isIE9, isIE, isEdge } from 'core/util/index'\n...
2016-10-11T03:17:35
huggingface/transformers
80f20e0ff8786087bb581fd4ce1eba2d69d62352
1d81247b0c17f78c5076fa4966025fa7b92e0a88
[Qwen3-next] Fix dimension mismatch in torch_chunk_gated_delta_rule and torch_recurrent_gated_delta_rule (#40963) (#41036) * fix mismatched dims for qwen3 next * propagate changes * chore: renamed tot_heads to total_sequence_length * Apply suggestion from @vasqu Co-authored-by: Anton Vlasjuk <73884904+vasqu@users....
[ { "path": "src/transformers/models/qwen3_next/modeling_qwen3_next.py", "patch": "@@ -458,15 +458,15 @@ def torch_chunk_gated_delta_rule(\n x.transpose(1, 2).contiguous().to(torch.float32) for x in (query, key, value, beta, g)\n ]\n \n- batch_size, sequence_length, num_heads, k_head_dim = key....
2025-09-24T11:18:27
denoland/deno
4e144a8fbf9725def62825da42b8e42110a89606
9018c8ccf2b735b1f34c5881a3cfc0646f854bb8
fix(ext/node): define process.versions.sqlite (#31277) This will make Node.js compat tests for sqlite run (previously they were skipped because the version was not defined).
[ { "path": "ext/node/polyfills/_process/process.ts", "patch": "@@ -200,6 +200,7 @@ export const versions = {\n unicode: \"14.0\",\n ngtcp2: \"0.8.1\",\n nghttp3: \"0.7.0\",\n+ sqlite: \"3.49.0\",\n // Will be filled when calling \"__bootstrapNodeProcess()\",\n deno: \"\",\n v8: \"\",", "addi...
2025-11-13T17:48:06
vuejs/vue
5b4b9269a52548034ff72c0fbd1cb20d897647f8
be6e050b89c8bcb904a30a0a5f435430d118b985
avoid updating input value during IME composition (fix #3894)
[ { "path": "src/platforms/web/runtime/modules/dom-props.js", "patch": "@@ -34,7 +34,7 @@ function updateDOMProps (oldVnode: VNodeWithData, vnode: VNodeWithData) {\n elm._value = cur\n // avoid resetting cursor position when value is the same\n const strCur = cur == null ? '' : String(cur)\n...
2016-10-11T03:15:34
ggml-org/llama.cpp
ef476916bba4b44f44be0c98babc1cb025968e75
d82f6aa34a216f5df1945cdfe121ba5e6cd80be0
CANN: FIx compiler warnings (#15661) Signed-off-by: noemotiovon <757486878@qq.com>
[ { "path": "ggml/src/ggml-cann/ggml-cann.cpp", "patch": "@@ -1155,7 +1155,7 @@ namespace {\n * @note The workspace buffer used in this function is managed globally and reused\n * across calls. This reduces overhead from repeated memory allocation and deallocation.\n */\n-static void weight_format_to...
2025-08-30T02:18:35
huggingface/transformers
65dcd66cc852f552c6c34d1ef898f891f3ad3f21
43a613c8da4d34b32935e1cc3b169c129e040155
🚨 [V5] Remove deprecated training arguments (#41017) * Remove deprecated training arguments from V5 Signed-off-by: Yuanyuan Chen <cyyever@outlook.com> * Remove deprecated training arguments from V5 Signed-off-by: Yuanyuan Chen <cyyever@outlook.com> * Fix comments Signed-off-by: Yuanyuan Chen <cyyever@outlook.co...
[ { "path": "examples/pytorch/question-answering/trainer_qa.py", "patch": "@@ -83,7 +83,7 @@ def evaluate(self, eval_dataset=None, eval_examples=None, ignore_keys=None, metr\n # Only the main node log the results by default\n self.log(metrics)\n \n- if self.args.tpu_metrics_debu...
2025-09-24T10:01:27
denoland/deno
06709834066d278a9ecee0cfb569029e325dbe3f
05bc6360e741d65f9f667782709d1de8e4c17eaa
fix(config): support UTF-16 surrogate pairs in unicode escape sequences in json config (#31264)
[ { "path": "Cargo.lock", "patch": "@@ -5554,9 +5554,9 @@ dependencies = [\n \n [[package]]\n name = \"jsonc-parser\"\n-version = \"0.27.0\"\n+version = \"0.27.1\"\n source = \"registry+https://github.com/rust-lang/crates.io-index\"\n-checksum = \"7ec4ac49f13c7b00f435f8a5bb55d725705e2cf620df35a5859321595102eb...
2025-11-13T10:37:39
vuejs/vue
be6e050b89c8bcb904a30a0a5f435430d118b985
86f0d114ec6f3aa670ec5cba82b75d5dfc05c119
fix `mounted` not called for manually mounted instance with parent (fix #3898)
[ { "path": "src/core/instance/lifecycle.js", "patch": "@@ -64,9 +64,9 @@ export function lifecycleMixin (Vue: Class<Component>) {\n vm._update(vm._render(), hydrating)\n }, noop)\n hydrating = false\n- // root instance, call mounted on self\n- // mounted is called for child components in ...
2016-10-11T03:03:21
ggml-org/llama.cpp
81017865ee444cf49ce0136f2be1e41a0270ff91
60e5eee31f1af9bb579ac45380e3857d610020b9
CUDA: fix bug in rms_norm fusion (#15660) * CUDA: fix bug in rms_norm fusion * Fix bug for OP_REPEAT * Fix index for add
[ { "path": "ggml/src/ggml-cuda/binbcast.cu", "patch": "@@ -57,7 +57,11 @@ static __global__ void k_bin_bcast(const src0_t * src0, const src1_t * src1, dst\n const int i10 = i0 % ne10;\n \n float result = src0_row ? (float) src0_row[i0] : 0.0f;\n- result = (..., (result = bin_op(result,...
2025-08-29T13:30:06
huggingface/transformers
43a613c8da4d34b32935e1cc3b169c129e040155
f64354e89a55a456e024b301468da2dbb10e11b3
Update ruff to 0.13.1 + target Python 3.10 + apply fixes (#37809) Update ruff to 0.13.1 target it to Python 3.10 and apply its fixes Signed-off-by: Yuanyuan Chen <cyyever@outlook.com> Co-authored-by: Yih-Dar <2521628+ydshieh@users.noreply.github.com>
[ { "path": "pyproject.toml", "patch": "@@ -14,7 +14,7 @@ exclude_lines = [\n ]\n \n [tool.ruff]\n-target-version = \"py39\"\n+target-version = \"py310\"\n line-length = 119\n \n [tool.ruff.lint]\n@@ -27,7 +27,10 @@ line-length = 119\n # UP031: Use format specifiers instead of percent format\n # UP004: Class ...
2025-09-24T06:37:21
denoland/deno
05bc6360e741d65f9f667782709d1de8e4c17eaa
e9d6557ea5daf321dbf0f1788f571d3e982ae29b
fix(node:console): ensure that the node:console implementation has an implementation for `emitWarning` in scope (#31263) Introduces the emitWarning function from the process module to enable warning capabilities within the console constructor implementation. This fixes a bug where the `time`, `countReset` and `timeLo...
[ { "path": "ext/node/polyfills/internal/console/constructor.mjs", "patch": "@@ -3,6 +3,7 @@\n \n import { op_preview_entries } from \"ext:core/ops\";\n import { primordials } from \"ext:core/mod.js\";\n+import { emitWarning } from \"node:process\";\n const {\n ArrayIsArray,\n ArrayFrom,", "additions"...
2025-11-13T09:33:50
vuejs/vue
86f0d114ec6f3aa670ec5cba82b75d5dfc05c119
3446d1485d36b91ef42c53268cb69ecb047538a5
fix dependency collection for multi-nested arrays (fix #3883)
[ { "path": "src/core/observer/index.js", "patch": "@@ -155,10 +155,7 @@ export function defineReactive (\n childOb.dep.depend()\n }\n if (Array.isArray(value)) {\n- for (let e, i = 0, l = value.length; i < l; i++) {\n- e = value[i]\n- e && e.__ob__ && ...
2016-10-11T02:55:15
huggingface/transformers
99b0995138c17ef953959c70f35cb2bdc41111a2
00f3d90720957cb4a723d29004424368025b7ae6
Remove bad test skips (#41109) * remove bad skips * remove more * fix inits
[ { "path": "src/transformers/models/d_fine/modeling_d_fine.py", "patch": "@@ -459,6 +459,12 @@ def _init_weights(self, module):\n nn.init.constant_(layer.layers[-1].weight, 0)\n nn.init.constant_(layer.layers[-1].bias, 0)\n \n+ if hasattr(module, \"reg_scale...
2025-09-23T18:39:28
ggml-org/llama.cpp
60e5eee31f1af9bb579ac45380e3857d610020b9
009b709d6efd24820ac67765ed339a72dc797814
chat : Seed OSS thinking + tool call support (#15552) * Reasoning and tool-calling support for Seed OSS * Fix grammar and partial parsing * Whitespace * New chat template * Update common/chat.cpp Co-authored-by: Sigbjørn Skjæret <sigbjorn.skjaeret@scala.com> * Update common/chat.cpp Co-authored-by: Sigbjørn Skj...
[ { "path": "common/chat.cpp", "patch": "@@ -622,6 +622,7 @@ const char * common_chat_format_name(common_chat_format format) {\n case COMMON_CHAT_FORMAT_COMMAND_R7B: return \"Command R7B\";\n case COMMON_CHAT_FORMAT_GRANITE: return \"Granite\";\n case COMMON_CHAT_FORMAT_GPT_OSS: return...
2025-08-29T12:53:41
denoland/deno
e9d6557ea5daf321dbf0f1788f571d3e982ae29b
a664ebebad8d08bf3c4220293d85d134d466249f
chore: try to fix promote_to_release workflow (#31215)
[ { "path": ".github/workflows/promote_to_release.yml", "patch": "@@ -46,20 +46,8 @@ jobs:\n Expand-Archive -Path \"denort-windows.zip\" -DestinationPath \".\"\n \n - name: Run patchver for Windows\n- shell: pwsh\n run: |\n- deno install -g -A -n patchver https://deno.l...
2025-11-12T22:12:21
huggingface/transformers
00f3d90720957cb4a723d29004424368025b7ae6
cfa022e71996e3a3dc8eb9b495716fa9d3447b5d
Fix `_get_test_info` for inherited tests (#41106) * fix _get_test_info * fix patched * add comment * ruff --------- Co-authored-by: ydshieh <ydshieh@users.noreply.github.com>
[ { "path": "src/transformers/testing_utils.py", "patch": "@@ -3357,15 +3357,27 @@ def _get_test_info():\n stack_from_inspect = inspect.stack()\n # but visit from the top frame to the most recent frame\n \n+ actual_test_file, _actual_test_class = test_file, test_class\n test_frame, test_obj, te...
2025-09-23T17:35:24
ggml-org/llama.cpp
e8d99dd0b67f2ecc1e45fca8074a3a18c3e036d2
a8bca68f727844e7dcf24a956003b3c2039ea563
nvidia nemotron nano v2 (nemotronh) (#15507) * feat: Add NEMOTRONH to python arch enum https://github.com/ggml-org/llama.cpp/issues/nemotron-nano-15409 Branch: gabe-l-hart/nvidia-nemotron-nano-15409 Signed-off-by: Gabe Goodhart <ghart@us.ibm.com> * feat: Add NEMOTRONH to c++ arch enum https://github.com/ggml-org/l...
[ { "path": "convert_hf_to_gguf.py", "patch": "@@ -7546,9 +7546,13 @@ def __init__(self, *args, **kwargs):\n ]\n \n # n_group and d_inner are used during reshape_tensors for mamba2\n- self.d_model = self.find_hparam([\"hidden_size\", \"d_model\"])\n- self.n_group = self.find_hpar...
2025-08-29T00:39:31
vuejs/vue
3446d1485d36b91ef42c53268cb69ecb047538a5
5925ad3bd2781a05484dde5bf7a22604ad66ebf5
support functional components as named slot (fix #3872)
[ { "path": "src/core/instance/render.js", "patch": "@@ -232,7 +232,7 @@ export function resolveSlots (\n child = children[i]\n // named slots should only be respected if the vnode was rendered in the\n // same context.\n- if (child.context === context &&\n+ if ((child.context === context ||...
2016-10-11T02:41:14
denoland/deno
099f8d60f2502cea7281744e6011e3f704aa3fa8
1edd1fb6573507d2ec3fc8d57c634d7f3379b4dd
fix(unstable): don't panic on invalid reported lint range (#31261) When a lint diagnostic contained an invalid range where the `start` value was bigger than the `end` value, we'd panic when passing the range to `dprint`. We should ensure that the range is correct right when we're creating the lint diagnostic instead. ...
[ { "path": "cli/js/40_lint.js", "patch": "@@ -391,6 +391,12 @@ export class Context {\n const start = range[0];\n const end = range[1];\n \n+ if (start > end) {\n+ throw new RangeError(\n+ `Invalid range. Start value is bigger than end value: [${start}, ${end}]`,\n+ );\n+ }\n+\...
2025-11-12T14:11:40
huggingface/transformers
cfa022e71996e3a3dc8eb9b495716fa9d3447b5d
869735d37d0f929311ac6611728c482a4414ba8c
[tests] gpt2 + `CausalLMModelTester` (#41003) * tmp commit * tmp commit * tmp commit * rm old GPT2ModelTester * nit bug * add facilities for encoder-decoder tests; add comments on ALL overwrites/extra fns * vision_encoder_decoder
[ { "path": "tests/causal_lm_tester.py", "patch": "@@ -316,6 +316,27 @@ def test_token_classification_model(self):\n (self.model_tester.batch_size, self.model_tester.seq_length, self.model_tester.num_labels),\n )\n \n+ def test_question_answering_model(self):\n+ if self.model_tes...
2025-09-23T17:07:06
ggml-org/llama.cpp
a8bca68f727844e7dcf24a956003b3c2039ea563
c97dc093912ad014f6d22743ede0d4d7fd82365a
fix: Compute the full sum in llama-eval-callback, not just the sum of printed values (#15637) This makes it much easier to compare between llama.cpp and transformers! https://github.com/ggml-org/llama.cpp/issues/nemotron-nano-15409 Branch: gabe-l-hart/nvidia-nemotron-nano-15409 Signed-off-by: Gabe Goodhart <ghart@us...
[ { "path": "examples/eval-callback/eval-callback.cpp", "patch": "@@ -28,9 +28,40 @@ static std::string ggml_ne_string(const ggml_tensor * t) {\n return str;\n }\n \n+static float ggml_get_float_value(uint8_t * data, ggml_type type, const size_t * nb, size_t i0, size_t i1, size_t i2, size_t i3) {\n+ si...
2025-08-28T20:27:36
denoland/deno
1edd1fb6573507d2ec3fc8d57c634d7f3379b4dd
5ed0646bc4c93f3c3d72d07832760c21269f7276
fix(ext/node): ensure 'exit' event is fired only once for `worker_threads` (#31231) Closes #30013 The `'exit'` event in `node:worker_threads` was not consistently fired, or in some cases emitted multiple times, diverging from Node.js behavior.
[ { "path": "ext/node/polyfills/worker_threads.ts", "patch": "@@ -99,6 +99,7 @@ class NodeWorker extends EventEmitter {\n #messagePromise = undefined;\n #controlPromise = undefined;\n #workerOnline = false;\n+ #exited = false;\n // \"RUNNING\" | \"CLOSED\" | \"TERMINATED\"\n // \"TERMINATED\" means...
2025-11-12T13:15:44
vuejs/vue
5925ad3bd2781a05484dde5bf7a22604ad66ebf5
f9bef75a3425213d2f1ff3bc7fb27322617bc233
tweak select IE fix to reduce duplicate call
[ { "path": "src/platforms/web/runtime/directives/model.js", "patch": "@@ -20,7 +20,7 @@ if (isIE9) {\n }\n \n export default {\n- bind (el, binding, vnode) {\n+ inserted (el, binding, vnode) {\n if (process.env.NODE_ENV !== 'production') {\n if (!modelableTagRE.test(vnode.tag)) {\n warn(\...
2016-10-11T01:23:49
ggml-org/llama.cpp
6c442f42ff25564a0cd6b1435d9abc1b0178eac5
73804145ab6c06888e314046abf08f66a0133679
ggml-cpu: fix invalid hsum build in debug s390x (#15634) Signed-off-by: Aaron Teo <aaron.teo1@ibm.com>
[ { "path": "ggml/src/ggml-cpu/ggml-cpu-impl.h", "patch": "@@ -489,7 +489,7 @@ inline static int16x8_t vec_padd_s16(int16x8_t a, int16x8_t b) {\n /**\n * @see https://github.com/ggml-org/llama.cpp/pull/14037\n */\n-inline float vec_hsum(float32x4_t v) {\n+inline static float vec_hsum(float32x4_t v) {\n ...
2025-08-28T14:39:27
huggingface/transformers
869735d37d0f929311ac6611728c482a4414ba8c
71717ce91c8ab4a9629f1d0d5ab7660b699e5cbd
🚨 [generate] update paligemma mask updates (and other assisted generation-related fixes) (#40917) * tmp * fix modular inheritance * nit * paligemma 1 doesn't have swa * use same pattern as in models with hybrid layers * PR comments * helium also needs layer_typed (bc it relies on gemma) * paligemma/gemma3: sam...
[ { "path": "src/transformers/masking_utils.py", "patch": "@@ -1073,8 +1073,8 @@ def create_masks_for_generate(\n **kwargs,\n ):\n \"\"\"\n- This function mimics how we create the masks in the `modeling_xxx.py` files, and is used in `generate` in order\n- to easily create the masks in advance, w...
2025-09-23T16:20:00
denoland/deno
5ed0646bc4c93f3c3d72d07832760c21269f7276
30cf1f41623fdfc0bf3df714a723e5f6864299a6
fix(node/crypto): respect authTagLength in createCipheriv for GCM cip… (#31253) This PR fixes a bug in `node:crypto.createCipheriv` where the `authTagLength` option was ignored for AES-GCM ciphers, resulting in a fixed 16-byte authentication tag regardless of the specified value. The fix ensures both encryption and d...
[ { "path": "ext/node/ops/crypto/cipher.rs", "patch": "@@ -25,8 +25,8 @@ enum Cipher {\n Aes128Ecb(Box<ecb::Encryptor<aes::Aes128>>),\n Aes192Ecb(Box<ecb::Encryptor<aes::Aes192>>),\n Aes256Ecb(Box<ecb::Encryptor<aes::Aes256>>),\n- Aes128Gcm(Box<Aes128Gcm>),\n- Aes256Gcm(Box<Aes256Gcm>),\n+ Aes128Gcm(...
2025-11-12T12:58:17
vuejs/vue
f9bef75a3425213d2f1ff3bc7fb27322617bc233
74e4e11b4478439e581818c483d27038cbbd62fb
fix select multiple first option auto-selected in Chrome/FF (fix #3852)
[ { "path": "src/platforms/web/runtime/modules/attrs.js", "patch": "@@ -68,6 +68,15 @@ function setAttr (el: Element, key: string, value: any) {\n }\n \n export default {\n- create: updateAttrs,\n+ create: function initAttrs (_: VNodeWithData, vnode: VNodeWithData) {\n+ updateAttrs(_, vnode)\n+ // #38...
2016-10-11T01:23:25
ggml-org/llama.cpp
73804145ab6c06888e314046abf08f66a0133679
c8d0d14e77c3c45df5cbbddde9c2b4c377ec4e7a
ggml : fix SSM_SCAN for n_groups > 1 (#15625)
[ { "path": "ggml/src/ggml-cpu/ops.cpp", "patch": "@@ -9003,8 +9003,7 @@ static void ggml_compute_forward_ssm_scan_f32(\n GGML_ASSERT(src4->nb[0] == sizeof(float));\n GGML_ASSERT(src5->nb[0] == sizeof(float));\n GGML_ASSERT(src6->nb[0] == sizeof(int32_t));\n- // allows optimizing the modulo sin...
2025-08-28T14:11:36
huggingface/transformers
71717ce91c8ab4a9629f1d0d5ab7660b699e5cbd
946e5f95ea0894e5c88f7915547ed3ffcafa56cd
docs: Fix Tool Use links and remove dead RAG links (#41104) docs: Fix tool use links. Remove dead RAG links. Fix style
[ { "path": "benchmark_v2/run_benchmarks.py", "patch": "@@ -357,7 +357,9 @@ def main():\n )\n \n parser.add_argument(\n- \"--token\", type=str, help=\"HuggingFace token for dataset uploads (if not provided, will use HF_TOKEN environment variable)\"\n+ \"--token\",\n+ type=str,\n+ ...
2025-09-23T16:18:49
denoland/deno
30cf1f41623fdfc0bf3df714a723e5f6864299a6
56dd527ae03578224cd9e09aedc9c1b9895003c4
fix(ext/node): implement performance.timerify() (#31238) Adds the missing implementation for `performance.timerify()` in `node:perf_hooks`, which previously resulted in a "Not implemented" error. Fixes #31115
[ { "path": "ext/node/polyfills/perf_hooks.js", "patch": "@@ -3,7 +3,6 @@\n // TODO(petamoriken): enable prefer-primordials for node polyfills\n // deno-lint-ignore-file prefer-primordials\n \n-import { notImplemented } from \"ext:deno_node/_utils.ts\";\n import { performance, PerformanceEntry } from \"ext:de...
2025-11-12T12:55:02
ggml-org/llama.cpp
c8d0d14e77c3c45df5cbbddde9c2b4c377ec4e7a
84ab83cc0b4b7e769451ee48e4c7d1acef91ef25
kv-cache : fix find_slot to not search for continuous slot (#15638) ggml-ci
[ { "path": "src/llama-kv-cache.cpp", "patch": "@@ -540,7 +540,7 @@ llama_kv_cache::slot_info_vec_t llama_kv_cache::prepare(const std::vector<llama_\n \n for (const auto & ubatch : ubatches) {\n // only find a suitable slot for the ubatch. don't modify the cells yet\n- const auto sinfo_new ...
2025-08-28T14:09:05
huggingface/transformers
946e5f95ea0894e5c88f7915547ed3ffcafa56cd
870add3dafbf388b97581f1eb8945960bf047a7e
fix wrong height and width when read video use torchvision (#41091)
[ { "path": "src/transformers/video_utils.py", "patch": "@@ -546,8 +546,8 @@ def sample_indices_fn(metadata, **kwargs):\n metadata.update(\n {\n \"frames_indices\": indices,\n- \"height\": video.shape[1],\n- \"width\": video.shape[2],\n+ \"height\": vid...
2025-09-23T12:35:44
vuejs/vue
74e4e11b4478439e581818c483d27038cbbd62fb
8d2fc8e8ac435c6f37aa91d4e58c78797f99bdd9
fix v-on handler with whitespaces (fix #3893)
[ { "path": "src/compiler/codegen/events.js", "patch": "@@ -1,6 +1,6 @@\n /* @flow */\n \n-const simplePathRE = /^[A-Za-z_$][\\w$]*(?:\\.[A-Za-z_$][\\w$]*|\\['.*?'\\]|\\[\".*?\"\\]|\\[\\d+\\]|\\[[A-Za-z_$][\\w$]*\\])*$/\n+const simplePathRE = /^\\s*[A-Za-z_$][\\w$]*(?:\\.[A-Za-z_$][\\w$]*|\\['.*?'\\]|\\[\".*?...
2016-10-10T23:30:19
denoland/deno
5545b3b0e4a585e5a878fea3932f78d24f42f900
0d838faf17d5174a1e5894d77f533d754f4b05c5
fix: update JSDoc for Deno.cwd() API (#31256) This was missed in https://github.com/denoland/deno/pull/27192.
[ { "path": "cli/tsc/dts/lib.deno.ns.d.ts", "patch": "@@ -1700,9 +1700,6 @@ declare namespace Deno {\n *\n * Throws {@linkcode Deno.errors.NotFound} if directory not available.\n *\n- * Requires `allow-read` permission.\n- *\n- * @tags allow-read\n * @category Runtime\n */\n export func...
2025-11-12T09:09:41
huggingface/transformers
ae606928217bdb32c9c3acd997b5ef9bf523cab5
f682797866f06f8fc88a296ab52da18910d9acae
Remove unused arguments (#40916) * Fix unused arguments Signed-off-by: Yuanyuan Chen <cyyever@outlook.com> * More fixes Signed-off-by: Yuanyuan Chen <cyyever@outlook.com> --------- Signed-off-by: Yuanyuan Chen <cyyever@outlook.com>
[ { "path": "src/transformers/generation/candidate_generator.py", "patch": "@@ -524,7 +524,7 @@ def get_candidates(self, input_ids: torch.LongTensor) -> tuple[torch.LongTensor,\n self.assistant_kwargs.pop(\"attention_mask\", None)\n \n assistant_output = self.assistant_model.generate(**generat...
2025-09-23T11:40:51
ggml-org/llama.cpp
84ab83cc0b4b7e769451ee48e4c7d1acef91ef25
55042b3692cb1467c9ee15c62c4a9fbf180f89e3
model : jina-embeddings-v3 support (#13693) * initial jina-embeddings-v3 support * initial jina-embeddings-v3 support * initial jina-embeddings-v3 support * fix vocab parsing with only tokenizer.json * set mask token lstrip attribute * additional unk_token_id fallback just in case [no ci] * revert vocab_size() c...
[ { "path": "common/arg.cpp", "patch": "@@ -2555,15 +2555,15 @@ common_params_context common_params_parser_init(common_params & params, llama_ex\n {\"--lora\"}, \"FNAME\",\n \"path to LoRA adapter (can be repeated to use multiple adapters)\",\n [](common_params & params, const std::str...
2025-08-28T13:49:50
vuejs/vue
de199f9bbd7ac8a2ad949b4e8677badb1536a027
f59e903d0b695eb1427eef4516589a1b56c11116
allow 2 root nodes with v-if and v-else (#3887) * allow 2 root nodes with v-if and v-else * fix compiler-options test with less specific text
[ { "path": "src/compiler/parser/index.js", "patch": "@@ -153,8 +153,9 @@ export function parse (\n checkRootConstraints(root)\n } else if (process.env.NODE_ENV !== 'production' && !stack.length && !warned) {\n // allow 2 root elements with v-if and v-else\n- if ((root.attrsMap.ha...
2016-10-09T20:33:23
denoland/deno
0d838faf17d5174a1e5894d77f533d754f4b05c5
0c9598d169d238d595882361d06d33bb620f2c57
fix(ext/napi): suppress deprecated Buffer warnings (#31245)
[ { "path": "ext/napi/lib.rs", "patch": "@@ -391,7 +391,7 @@ pub struct Env {\n pub last_error: napi_extended_error_info,\n pub last_exception: Option<v8::Global<v8::Value>>,\n pub global: v8::Global<v8::Object>,\n- pub buffer_constructor: v8::Global<v8::Function>,\n+ pub create_buffer: v8::Global<v8:...
2025-11-11T06:02:29
huggingface/transformers
f682797866f06f8fc88a296ab52da18910d9acae
f4a6c65951b0d6c76418b008200df8b57f410cc5
Fix typing (#40788) * Fix optional typing Signed-off-by: Yuanyuan Chen <cyyever@outlook.com> * Fix optional typing Signed-off-by: Yuanyuan Chen <cyyever@outlook.com> * Fix schema typing Signed-off-by: Yuanyuan Chen <cyyever@outlook.com> * Fix typing * Fix typing * Fix typing * Fix typing * Use np.ndarray Si...
[ { "path": "src/transformers/audio_utils.py", "patch": "@@ -23,8 +23,11 @@\n import warnings\n from collections.abc import Sequence\n from io import BytesIO\n-from typing import Any, Optional, Union\n+from typing import TYPE_CHECKING, Any, Optional, Union\n \n+\n+if TYPE_CHECKING:\n+ import torch\n import...
2025-09-23T11:36:02
ggml-org/llama.cpp
d35a1e8c41f747548775225973a99507896a8c61
46d9caa27a0281150e8cf082308c0f9e7576ebe5
cli : change log to warning to explain reason for stopping (#15604) * Change to warn instead of debug, to explain reason for stopping. * Update tools/main/main.cpp Fix printing --2 Co-authored-by: Georgi Gerganov <ggerganov@gmail.com> --------- Co-authored-by: Georgi Gerganov <ggerganov@gmail.com>
[ { "path": "tools/main/main.cpp", "patch": "@@ -587,12 +587,12 @@ int main(int argc, char ** argv) {\n \n if (n_past + (int) embd.size() >= n_ctx) {\n if (!params.ctx_shift){\n- LOG_DBG(\"\\n\\n%s: context full and context shift is disabled => stoppi...
2025-08-28T07:48:20
vuejs/vue
addb461e3c8c9b2041c0f44892cdb58a40b26b64
adae5caaeea2c8bd18e21a87d83ed7251b862a67
fix ssr bundle renderer error on commonjs exports (fix #3867)
[ { "path": "src/server/run-in-vm.js", "patch": "@@ -30,7 +30,7 @@ export default function runInVm (code, _context = {}) {\n compiledWrapper.call(m.exports, m.exports, require, m)\n const res = Object.prototype.hasOwnProperty.call(m.exports, 'default')\n ? m.exports.default\n- : m\n+ :...
2016-10-07T21:42:42
denoland/deno
0c9598d169d238d595882361d06d33bb620f2c57
19c7f1fc5d6ec4e61273f952761696bad3e478ca
fix(check): ensure `@types/node` is cached when already in resolution (#31235)
[ { "path": "cli/graph_util.rs", "patch": "@@ -792,7 +792,9 @@ impl ModuleGraphBuilder {\n && graph.has_node_specifier\n && graph.graph_kind().include_types()\n {\n- npm_installer.inject_synthetic_types_node_package().await?;\n+ npm_installer\n+ .inject_synthetic_types_node_pa...
2025-11-10T13:10:11
ggml-org/llama.cpp
1e7489745a74996fc36e8fd05b73aa16bc184e0c
1cf123a343ab7ca5586aacb9e0a1d2de7fe33be4
CANN: refactor mask handling and improve performance in FA (#15561) * CANN(flash-attn): refactor mask handling and improve performance 1. Refactored the mask computation in Flash Attention, unified the logic without separating prefill and decode. 2. Optimized performance in non-alibi scenarios by reducing one repeat ...
[ { "path": "ggml/src/ggml-cann/aclnn_ops.cpp", "patch": "@@ -1427,17 +1427,17 @@ static void aclnn_pow_tensor_tensor(ggml_backend_cann_context& ctx,\n static void aclnn_get_slope_inner(ggml_backend_cann_context& ctx, void* slope_buffer,\n float m, int64_t size, float start, float stop, float step){\n ...
2025-08-27T09:21:41
huggingface/transformers
f4a6c65951b0d6c76418b008200df8b57f410cc5
89e0f472f4d4f637949e44d0b3aa9b204139849c
Fix typos in documentation (#41087) Signed-off-by: Yuanyuan Chen <cyyever@outlook.com>
[ { "path": "docs/source/en/chat_templating.md", "patch": "@@ -189,7 +189,7 @@ model.generate(**formatted_chat)\n \n ## Model training\n \n-Training a model with a chat template is a good way to ensure the template matches the tokens the model was trained on. Apply the chat template as a preprocessing step to...
2025-09-23T11:27:04
vuejs/vue
adae5caaeea2c8bd18e21a87d83ed7251b862a67
463c9c9e086f919e61fe7fa74f1a8f0695693de3
Make forAlias regex lazy (fixes #3846) (#3859) The current forAliasRE has the first rule greedy (`.*?`), which will attempt to match whatever it can. This exposes a bug (#3846), where the regex fails if the template happens to have " in " or " of " in its last group. For instance, with the template `for key in [{bo...
[ { "path": "src/compiler/parser/index.js", "patch": "@@ -16,7 +16,7 @@ import {\n } from '../helpers'\n \n export const dirRE = /^v-|^@|^:/\n-export const forAliasRE = /(.*)\\s+(?:in|of)\\s+(.*)/\n+export const forAliasRE = /(.*?)\\s+(?:in|of)\\s+(.*)/\n export const forIteratorRE = /\\(([^,]*),([^,]*)(?:,([...
2016-10-07T21:40:17
denoland/deno
19c7f1fc5d6ec4e61273f952761696bad3e478ca
58f7435270bd018386ddb8f35ddc2494a0e8695f
fix(ext/node): truncate first non-hex value on Buffer.from (#31227)
[ { "path": "ext/node/polyfills/internal_binding/_utils.ts", "patch": "@@ -58,14 +58,35 @@ export function base64UrlToBytes(str: string) {\n return forgivingBase64UrlDecode(str);\n }\n \n+// https://github.com/nodejs/node/blob/591ba692bfe30408e6a67397e7d18bfa1b9c3561/deps/nbytes/src/nbytes.cpp#L144-L158\n+/...
2025-11-10T11:32:09